From bd3df5819ef9136c68e072365e46cfd558543918 Mon Sep 17 00:00:00 2001
From: Thomas Schmitt
Date: Fri, 15 Oct 2010 12:16:12 +0000
Subject: [PATCH] Included libjte in GNU xorriso
---
libisoburn/trunk/xorriso/AUTHORS_gnu_xorriso | 9 +++
.../trunk/xorriso/COPYRIGHT_gnu_xorriso | 11 ++-
libisoburn/trunk/xorriso/README_gnu_xorriso | 7 ++
libisoburn/trunk/xorriso/configure_ac.txt | 69 +++++++++++++++----
.../trunk/xorriso/make_xorriso_standalone.sh | 44 +++---------
libisoburn/trunk/xorriso/xorriso_eng.html | 36 +++++++++-
.../trunk/xorriso/xorriso_makefile_am.txt | 35 ++++++----
libisoburn/trunk/xorriso/xorriso_timestamp.h | 2 +-
8 files changed, 143 insertions(+), 70 deletions(-)
diff --git a/libisoburn/trunk/xorriso/AUTHORS_gnu_xorriso b/libisoburn/trunk/xorriso/AUTHORS_gnu_xorriso
index b2479ff0..cd4ebadc 100644
--- a/libisoburn/trunk/xorriso/AUTHORS_gnu_xorriso
+++ b/libisoburn/trunk/xorriso/AUTHORS_gnu_xorriso
@@ -3,4 +3,13 @@ Ben Jansens
Thomas Schmitt
Mario Danic
Vreixo Formoso Lopes
+Colin Plumb
+Tatu Ylonen
+Jim Kingdon
+Scott G. Miller
+Ulrich Drepper
+Richard Atterer
+Steve McIntyre
+George Danchev
+and possibly others who gave their copyright to Free Software Foundation, Inc.
diff --git a/libisoburn/trunk/xorriso/COPYRIGHT_gnu_xorriso b/libisoburn/trunk/xorriso/COPYRIGHT_gnu_xorriso
index c9918435..0260890d 100644
--- a/libisoburn/trunk/xorriso/COPYRIGHT_gnu_xorriso
+++ b/libisoburn/trunk/xorriso/COPYRIGHT_gnu_xorriso
@@ -3,15 +3,22 @@ Ben Jansens
Thomas Schmitt
Mario Danic ,
Vreixo Formoso
+Steve McIntyre
+George Danchev
-GNU xorriso is a compilation of
+GNU xorriso is a compilation of modules from libburnia-project.org :
xorriso Copyright (C) 2007-2010 Thomas Schmitt
libisoburn Copyright (C) 2007-2010 Vreixo Formoso, Thomas Schmitt
libisofs Copyright (C) 2007-2010 Vreixo Formoso, Mario Danic, Thomas Schmitt
libburn Copyright (C) 2002-2006 Derek Foreman, Ben Jansens
2006-2010 Mario Danic, Thomas Schmitt
-from libburnia-project.org with a license derived from GPLv2+.
+Further included is :
+libjte Copyright (C) 2000-2007 Free Software Foundation, Inc.
+ 2004-2010 Steve McIntyre
+ 2010-2010 George Danchev, Thomas Schmitt
+Originally they all are licensed directly or indirectly as GPLv2+.
+GNU xorriso is licensed by the following statement:
This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License version 3
diff --git a/libisoburn/trunk/xorriso/README_gnu_xorriso b/libisoburn/trunk/xorriso/README_gnu_xorriso
index b44db7c2..b6e2f03d 100644
--- a/libisoburn/trunk/xorriso/README_gnu_xorriso
+++ b/libisoburn/trunk/xorriso/README_gnu_xorriso
@@ -417,6 +417,13 @@ of old
Libburn. By Derek Foreman and
Ben Jansens
Copyright (C) 2002-2006 Derek Foreman and Ben Jansens
+
+GNU xorriso contains
+libjte
+Copyright (C) 2000-2007 Free Software Foundation, Inc.
+ 2004-2010 Steve McIntyre
+ 2010-2010 George Danchev, Thomas Schmitt
+
------------------------------------------------------------------------------
This text itself is
diff --git a/libisoburn/trunk/xorriso/configure_ac.txt b/libisoburn/trunk/xorriso/configure_ac.txt
index 08883fa0..15c63db7 100644
--- a/libisoburn/trunk/xorriso/configure_ac.txt
+++ b/libisoburn/trunk/xorriso/configure_ac.txt
@@ -215,7 +215,8 @@ then
fi
-AH_TEMPLATE([Libisofs_with_zliB], [Define to use compression via libz])
+AH_TEMPLATE([Libisofs_with_zliB], [Define to use compression via zlib])
+AH_TEMPLATE([LIBJTE_WITH_ZLIB], [Allow libjte to use zlib])
AC_ARG_ENABLE(zlib,
[ --enable-zlib Enable use of zlib by libisofs, default=yes],
, enable_zlib=yes)
@@ -225,41 +226,79 @@ dnl If not, erase this macro which would enable use of compress2() and others.
dnl Linking fails on SuSE 9.0 because zlib has compress2() but lacks
dnl compressBound(). So compressBound is the more modern thing to test.
dnl The empty parameter after "compressBound" causes -lz.
- ZLIB_DEF="-DLibisofs_with_zliB"
+ ZLIB_DEF=yes
AC_CHECK_HEADER(zlib.h, AC_CHECK_LIB(z, compressBound, , ZLIB_DEF= ), ZLIB_DEF= )
else
ZLIB_DEF=
fi
-if test x$ZLIB_DEF = x-DLibisofs_with_zliB
+if test x$ZLIB_DEF = xyes
then
AC_DEFINE([Libisofs_with_zliB], [])
+ AC_DEFINE([LIBJTE_WITH_ZLIB], [])
fi
+# libjte source is included in GNU xorriso. Enable it if zlib is enabled.
AH_TEMPLATE([Xorriso_with_libjtE],
[Define to use Jigdo Template Extraction via libjte])
AH_TEMPLATE([Libisofs_with_libjtE],
[Define to use Jigdo Template Extraction via libjte])
-AC_ARG_ENABLE(libjte,
-[ --enable-libjte Enable use of libjte by xorriso, default=yes],
- , enable_libjte=yes)
-if test "x$enable_libjte" = xyes; then
- LIBJTE_DEF=yes
- AC_CHECK_HEADER(libjte/libjte.h, AC_CHECK_LIB(jte, libjte_new, , LIBJTE_DEF= ), LIBJTE_DEF= )
-else
- LIBJTE_DEF=
-fi
-if test x$LIBJTE_DEF = xyes
+if test x$ZLIB_DEF = xyes
then
AC_DEFINE([Xorriso_with_libjtE], [])
AC_DEFINE([Libisofs_with_libjtE], [])
- LIBJTE_DEF="-DXorriso_with_libjtE -DLibisofs_with_libjtE"
+
+# >>> Only until built-in libjte becomes default with xorriso-standalone
+ AH_TEMPLATE([Xorriso_jte_standalonE], [Preliminary switch])
+ AC_DEFINE([Xorriso_jte_standalonE], [])
+
+ LIBJTE_DEF=yes
+ echo "enabled built-in libjte"
+else
+ LIBJTE_DEF=
+ echo "disabled libjte because zlib not enabled or not available"
+fi
+
+
+AH_TEMPLATE([THREADED_CHECKSUMS],
+ [Define to use multi-threading in built-in libjte])
+AC_ARG_ENABLE(jtethreads,
+[ --enable-jtethreads Enable multi-threading in libjte, default=yes],
+ , enable_jtethreads=yes)
+if test x$LIBJTE_DEF = xyes
+then
+ if test "x$enable_jtethreads" = xyes; then
+ AC_DEFINE([THREADED_CHECKSUMS], [])
+ echo "enabled multi-threading in libjte"
+ else
+ echo "disabled multi-threading in libjte"
+ fi
+
+fi
+
+
+AH_TEMPLATE([LIBJTE_WITH_LIBBZ2],
+ [Define to use libbz2 by built-in libjte])
+AC_ARG_ENABLE(libbz2,
+[ --enable-libbz2 Enable use of libbz2 by libjte, default=yes],
+ , enable_libbz2=yes)
+if test "x$enable_libbz2" = xyes -a x$LIBJTE_DEF = xyes ; then
+dnl Check whether there is the header for libbz2.
+ BZIP2_DEF=yes
+ AC_CHECK_HEADER(bzlib.h, AC_CHECK_LIB(bz2, BZ2_bzCompressInit, , BZIP2_DEF= ), BZIP2_DEF= )
+else
+ BZIP2_DEF=
+fi
+if test x$BZIP2_DEF = xyes
+then
+ AC_DEFINE([LIBJTE_WITH_LIBBZ2], [])
+ BZIP2_DEF="-DLIBJTE_WITH_LIBBZ2"
fi
AH_TEMPLATE([Libburn_use_libcdiO], [Define to use libcdio as system adapter])
AC_ARG_ENABLE(libcdio,
-[ --enable-libcdio Enable EXPERIMENTAL use of libcdio as system adapter, default=no],
+[ --enable-libcdio Enable EXPERIMENTAL use of libcdio as system adapter, default=no],
, enable_libcdio=no)
if test x$enable_libcdio = xyes; then
dnl Check whether there is libcdio-devel and libcdio-runtime.
diff --git a/libisoburn/trunk/xorriso/xorriso_eng.html b/libisoburn/trunk/xorriso/xorriso_eng.html
index d4359d63..de0982a2 100644
--- a/libisoburn/trunk/xorriso/xorriso_eng.html
+++ b/libisoburn/trunk/xorriso/xorriso_eng.html
@@ -83,6 +83,8 @@ but rather not with CD, DVD-R, DVD+R, BD-R.
eventually allow on GNU/Linux to get and set ACLs.
zlib and zlib-devel
eventually allow zisofs and gzip compression.
+libbz2 and libbz2-devel
+eventually allow bzip2 compression of Jigdo template files.
@@ -539,7 +541,7 @@ I.e. only with option -close "on".
-Libburnia software copies included in GNU xorriso:
+Software copies included in GNU xorriso:
-
@@ -588,12 +590,27 @@ cdrecord and mkisofs.
- Enhancements towards stable version 0.6.2:
-- - none yet -
+-
+New option -jigdo
+
+-
+New -as mkisofs options -jigdo-* , -md5-list , -checksum_algorithm_* as of genisoimage
+
+-
+New bootspecs mips_path= and mipsel_path= for Debian MIPS releases
+
+-
+New -as mkisofs options -mips-boot and -mipsel-boot
+
+
+
+-
+
-
- README 0.6.3
- xorriso_0.6.3 -help
@@ -608,13 +625,14 @@ installation see README)
-
xorriso-0.6.3.tar.gz
-(1670 KB).
+(1730 KB).
- A dynamically linked development version of xorriso can be obtained
from repositories of
libburnia-project.org.
xorriso is part of libisoburn/trunk and will get built by its "make".
+
- Be warned that the libraries in SVN and bzr are development versions with
possibly unstable API/ABI enhancements. Do not distribute development
versions for dynamic linking. Only release versions are safe for that.
@@ -636,6 +654,18 @@ versions for dynamic linking. Only release versions are safe for that.
But after the run of ./bootstrap, only
vanilla tools like make and gcc are needed.
+- The development version of GNU xorriso contains a copy of libjte-0.1.1
+which produces jigdo and template file together with the emerging ISO image,
+(By Free Software Foundation, Steve McIntyre, George Danchev,
+Thomas Schmitt)
+
+- Important: If desired, libjte has to be already installed when libisofs
+and libisoburn get built.
+- Download: svn co http://svn.openfmi.net/dev/people/danchev/jte libjte
+
+- Install: cd libjte ; ./bootstrap ; ./configure --prefix /usr ; make ; make install
+
+
-
diff --git a/libisoburn/trunk/xorriso/xorriso_makefile_am.txt b/libisoburn/trunk/xorriso/xorriso_makefile_am.txt
index c013cf27..f8a28049 100644
--- a/libisoburn/trunk/xorriso/xorriso_makefile_am.txt
+++ b/libisoburn/trunk/xorriso/xorriso_makefile_am.txt
@@ -32,18 +32,6 @@ xorriso_xorriso_CFLAGS =
xorriso_xorriso_LDADD = $(THREAD_LIBS) $(LIBBURN_ARCH_LIBS)
-# This looks quite ugly with make install: xorriso.c is compiled twice again
-#
-# Trying to create a build timestamp file
-#
-# BUILT_SOURCES = xorriso/xorriso_buildstamp.h
-# phony targets get rebuilt every time
-# .PHONY: xorriso/xorriso_buildstamp.h
-# xorriso/xorriso_buildstamp.h:
-# date -u '+#define Xorriso_build_timestamP "%Y.%m.%d.%H%M%S"' >xorriso/xorriso_buildstamp.h
-# cat xorriso/xorriso_buildstamp.h
-
-
xorriso_xorriso_SOURCES = \
\
xorriso/xorriso.h \
@@ -164,6 +152,26 @@ xorriso_xorriso_SOURCES = \
libisofs/md5.h \
libisofs/md5.c \
\
+ libjte/libjte.h \
+ libjte/libjte_private.h \
+ libjte/libjte.c \
+ libjte/jte.h \
+ libjte/jte.c \
+ libjte/checksum.h \
+ libjte/checksum.c \
+ libjte/endian.c \
+ libjte/endianconv.h \
+ libjte/md5.h \
+ libjte/md5.c \
+ libjte/rsync.h \
+ libjte/rsync.c \
+ libjte/sha1.h \
+ libjte/sha1.c \
+ libjte/sha256.h \
+ libjte/sha256.c \
+ libjte/sha512.h \
+ libjte/sha512.c \
+ \
libburn/async.c \
libburn/async.h \
libburn/back_hacks.h \
@@ -253,7 +261,6 @@ install-exec-hook:
-# Alternative to the disabled .PHONY above.
# Trying to create a build timestamp file semi-manually: make buildstamped
#
buildstamp:
@@ -283,8 +290,6 @@ indent: $(indent_files)
## ========================================================================= ##
# Extra things
-# nodist_pkgconfig_DATA = \
-# xorriso.pc
man_MANS = xorriso/xorriso.1
diff --git a/libisoburn/trunk/xorriso/xorriso_timestamp.h b/libisoburn/trunk/xorriso/xorriso_timestamp.h
index 38cdb4de..29c67408 100644
--- a/libisoburn/trunk/xorriso/xorriso_timestamp.h
+++ b/libisoburn/trunk/xorriso/xorriso_timestamp.h
@@ -1 +1 @@
-#define Xorriso_timestamP "2010.10.15.112050"
+#define Xorriso_timestamP "2010.10.15.121533"
diff --git a/libisoburn/trunk/xorriso/make_xorriso_standalone.sh b/libisoburn/trunk/xorriso/make_xorriso_standalone.sh
index facc12f8..c7d71a59 100755
--- a/libisoburn/trunk/xorriso/make_xorriso_standalone.sh
+++ b/libisoburn/trunk/xorriso/make_xorriso_standalone.sh
@@ -7,9 +7,9 @@
#
# This is a development tool which expects a special setup of directories.
# It is to be executed in a common parent of the directories
-# nglibisofs-develop libburn-develop libisoburn-develop
+# nglibisofs-develop jte-develop libburn-develop libisoburn-develop
# where tarballs or repository copies have been installed of
# libisofs libburn libisoburn
# obtained according to instructions on http://libburnia-project.org.
#
# It creates a new directory tree
@@ -120,10 +120,6 @@ copy_files xorriso/configure_ac.txt "$lone_dir"/configure.ac
copy_files xorriso/xorriso_makefile_am.txt "$lone_dir"/Makefile.am
-# copy_files xorriso/xorriso_pc_in.txt "$lone_dir"/xorriso.pc.in
-
-# echo "See end of xorriso/changelog.txt" >"$lone_dir"/TODO
-
# libisoburn
@@ -131,6 +127,7 @@ create_dir "$lone_dir"/libisoburn
copy_files \
libisoburn/*.[ch] \
"$lone_dir"/libisoburn
+copy_files COPYRIGHT "$lone_dir"/libisoburn
xorriso/convert_man_to_html.sh
@@ -198,6 +195,7 @@ copy_files \
xorriso/xorriso.1 \
xorriso/man_1_xorriso.html \
"$lone_dir"/xorriso
+copy_files COPYRIGHT "$lone_dir"/xorriso
copy_files xorriso/xorriso_buildstamp_none.h \
"$lone_dir"/xorriso/xorriso_buildstamp.h
@@ -223,6 +221,7 @@ copy_files libisofs/filters/*.[ch] "$lone_dir"/libisofs/filters
copy_files doc/susp_aaip*.txt "$lone_dir"/doc
copy_files doc/zisofs_format.txt "$lone_dir"/doc
copy_files doc/checksums.txt "$lone_dir"/doc
+copy_files doc/boot_sectors.txt "$lone_dir"/doc
copy_files COPYRIGHT "$lone_dir"/libisofs
test -e CONTRIBUTORS && cat CONTRIBUTORS >>"$lone_dir"/CONTRIBUTORS
@@ -230,35 +229,12 @@ test -e CONTRIBUTORS && cat CONTRIBUTORS >>"$lone_dir"/CONTRIBUTORS
cat version.h.in >> "$lone_dir"/version.h.in
-# <<< obsoleted patchings
-
-if test 1 = 0
-then
-
-# Change GNU macro name to POSIX name
-sed -e 's/FNM_FILE_NAME/FNM_PATHNAME/g' \
- "$lone_dir"/libisofs/tree.c
-
-# Filter out the semi-illegal TODO comments
-( cd "$lone_dir"/libisofs && grep '^[[:space:]]*//' *.[ch] | less )
-echo "Is it ok delete all shown //-lines ?"
-read yesno
-if test "$yesno" = "y" -o "$yesno" = "1"
-then
- for i in "$lone_dir"/libisofs/*.[ch]
- do
- # first copy attributes
- cp "$i" "$lone_dir"/libisofs/tmpfile
- # now filter away // lines
- grep -v '^[[:space:]]*//' <"$i" >"$lone_dir"/libisofs/tmpfile && \
- mv "$lone_dir"/libisofs/tmpfile "$i"
- done
-fi
-echo "Remaining // lines:"
-( cd "$lone_dir"/libisofs && grep '//' *.[ch] )
-
-fi
+# libjte
+create_dir "$lone_dir"/libjte
+goto_dir "$current_dir"/jte-develop
+copy_files *.[ch] "$lone_dir"/libjte
+copy_files COPYRIGHT "$lone_dir"/libjte
# libburn
@@ -7,9 +7,9 @@
# where tarballs or repository copies have been installed of
-# libisofs libburn libisoburn
+# libisofs jte libburn libisoburn
# obtained according to instructions on http://libburnia-project.org.
#